@@ -1,3 +1,4 @@
+import logging
 from zope.component import getUtility
 from zope.formlib import form
 from zope.interface import implements
@@ -17,6 +18,7 @@ from qi.jabberHelpdesk.interfaces import IChatRequest
 from qi.jabberHelpdesk import HelpdeskMessageFactory as _
 from qi.jabberHelpdesk.interfaces import IMessageHandler
 
+logger = logging.getLogger('qi.jabberHelpdesk')
 chatRequestFormView = named_template_adapter(ViewPageTemplateFile('chatRequest.pt'))
 class SmallTextAreaWidget(TextAreaWidget):
 	height = 5
@@ -38,10 +40,14 @@ class ChatRequestView(formbase.PageForm):
 		super(ChatRequestView,self).__init__(context,request)
 		
 	def availableAgents(self):
-		if self.mh.loadBot(self.context.botJid,self.context.botPassword,self.context.persistent):
-			return (len(self.mh.getAvailableAgents(self.context.botJid)),
-					len(self.mh.getAliveAgents(self.context.botJid)),)
-		return (0,0)
+		try:
+			if self.mh.loadBot(self.context.botJid,self.context.botPassword,self.context.persistent):
+				return (len(self.mh.getAvailableAgents(self.context.botJid)),
+						len(self.mh.getAliveAgents(self.context.botJid)),)
+			return (0,0)
+		except:
+			logger.error("Could not connect to bot:%s"%self.context.botJid)
+			return (0,0)
 
 	@property
 	def form_fields(self):
@@ -83,5 +89,8 @@ class ChatRequestView(formbase.PageForm):
 					IStatusMessage(self.request).addStatusMessage(_(u"No available agents."), type='error')
 			else:
 				IStatusMessage(self.request).addStatusMessage(_(u"Could not connect to helpdesk server"), type='error')
-		except Exception,e:
+				logger.error("Could not connect to bot:%s"%self.context.botJid)
+				
+		except:
 			IStatusMessage(self.request).addStatusMessage(_(u"Could not connect to helpdesk server"), type='error')
+			logger.error("Could not connect to bot:%s"%self.context.botJid)
