@@ -1,5 +1,5 @@
+import logging
 from Acquisition import aq_inner
-
 from zope import schema
 from zope.component import getMultiAdapter
 from zope.formlib import form
@@ -23,6 +23,8 @@ from Products.ATContentTypes.interfaces import IATImage
 
 from qi.jabberHelpdesk.interfaces import IMessageHandler
 
+logger = logging.getLogger('qi.jabberHelpdesk')
+
 class IHelpdeskPortlet(IPortletDataProvider):
 	"""
 	"""
@@ -77,9 +79,15 @@ class Renderer(base.Renderer):
 
 	@property
 	def availableAgents(self):
-		if self.mh.loadBot(self.helpdesk.botJid,self.helpdesk.botPassword,self.helpdesk.persistent):
-			return len(self.mh.getAvailableAgents(self.helpdesk.botJid))
-		return 0
+		"""
+		"""
+		try:		
+			if self.mh.loadBot(self.helpdesk.botJid,self.helpdesk.botPassword,self.helpdesk.persistent):
+				return len(self.mh.getAvailableAgents(self.helpdesk.botJid))
+			return 0
+		except:
+			return 0
+			
 	
 	@property
 	def available(self):
@@ -127,4 +135,4 @@ class EditForm(base.EditForm):
 	form_fields['targetHelpdesk'].custom_widget = UberMultiSelectionWidget
 	form_fields['portletImage'].custom_widget = UberMultiSelectionWidget
 	label = _(u"Edit helpdesk portlet")
-	description = _(u"This portlet lets people ask for online support from the helpdesk.")
\ No newline at end of file
+	description = _(u"This portlet lets people ask for online support from the helpdesk.")
