@@ -4,9 +4,9 @@ class IJabberHelpdeskKSSCommands(interface.Interface):
 	"""Livechat KSS commands
 	"""
 
-	def resetScrollbar(selector):
+	def jh_resetScrollbar(selector):
 		"""
 		"""
-	def resetInput(selector):
+	def jh_resetInput(selector):
 		"""
 		"""
\ No newline at end of file
